/*=========================================================================
   This file is part of the Cardboard Robot Console application.

   Copyright (C) 2012 Ken Ihara.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
=========================================================================*/

#import <Foundation/Foundation.h>
#import "CBJoystickListener.h"

#define CB_JOYSTICK_DEAD_ZONE   0.3     // Joystick values less than this should be considered zero

/** This class translates raw joystick input into robot commands */
@interface CBJoystickTranslator : NSObject <CBJoystickListener>

/** Are we currently translating joystick input? */
@property (assign, nonatomic) BOOL enabled;

- (void)resetInputs;
- (double)positionSumForMotor:(NSUInteger)motorNumber;
- (int)sourceCountForMotor:(NSUInteger)motorNumber;

// Inherited from CBJoystickListener
- (void)joystick:(DDHidJoystick *)joystick
           stick:(unsigned)stick
            axis:(unsigned)axis
    valueChanged:(double)value;

- (void)joystick:(DDHidJoystick *)joystick
      buttonDown:(unsigned)buttonNumber;

- (void)joystick:(DDHidJoystick *)joystick
        buttonUp:(unsigned)buttonNumber;

@end
